@@ -13,13 +13,13 @@ SCHEMA = 'schema'
 
 class DataclassSchemaFactory(SchemaFactoryABC):
 
-    def create(self, type_: Type, context: SchemaContext) -> Optional[SchemaABC]:
+    def create(self, type_: Type, default_value, context: SchemaContext) -> Optional[SchemaABC]:
         if not dataclasses.is_dataclass(type_):
             return
         context.register_schema(type_, DeferredSchema[type_](context, type_))
         # noinspection PyDataclass
         property_schemas = tuple(self._schema_for_field(f, context) for f in dataclasses.fields(type_))
-        schema = ObjectSchema[type_](type_, property_schemas)
+        schema = ObjectSchema[type_](type_, property_schemas, default_value=default_value)
         return schema
 
     @staticmethod
