@@ -1,9 +1,16 @@
 from dataclasses import dataclass
-from typing import Optional, List, Iterator, Type, TypeVar, Dict
+from typing import Optional, List, Iterator, Type
 
+from marshy.types import ExternalItemType
+
+from schemey._util import filter_none
+from schemey.json_output_context import JsonOutputContext
 from schemey.schema_abc import SchemaABC, T
 from schemey.schema_error import SchemaError
 
+INTEGER = 'integer'
+NUMBER = 'number'
+
 
 @dataclass(frozen=True)
 class NumberSchema(SchemaABC[T]):
@@ -12,12 +19,9 @@ class NumberSchema(SchemaABC[T]):
     exclusive_minimum: bool = False
     maximum: Optional[T] = None
     exclusive_maximum: bool = True
+    default_value: Optional[T] = None
 
-    def get_schema_errors(self,
-                          item: T,
-                          defs: Optional[Dict[str, SchemaABC]],
-                          current_path: Optional[List[str]] = None,
-                          ) -> Iterator[SchemaError]:
+    def get_schema_errors(self, item: T, current_path: Optional[List[str]] = None) -> Iterator[SchemaError]:
         if not isinstance(item, self.item_type):
             if not (self.item_type is float and isinstance(item, int)):
                 yield SchemaError(current_path, 'type', item)
@@ -30,3 +34,14 @@ class NumberSchema(SchemaABC[T]):
             yield SchemaError(current_path, 'maximum', item)
         if self.exclusive_maximum and self.maximum is not None and item == self.maximum:
             yield SchemaError(current_path, 'exclusive_maximum', item)
+
+    def to_json_schema(self, json_output_context: Optional[JsonOutputContext] = None) -> Optional[ExternalItemType]:
+        exclusive_minimum = self.exclusive_minimum
+        exclusive_maximum = self.exclusive_maximum
+        return filter_none(dict(
+            type=INTEGER if self.item_type is int else NUMBER,
+            minimum=self.minimum,
+            exclusiveMinimum=exclusive_minimum if exclusive_minimum != NumberSchema.exclusive_minimum else None,
+            maximum=self.maximum,
+            exclusiveMaximum=exclusive_maximum if exclusive_maximum != NumberSchema.exclusive_maximum else None
+        ))
