@@ -8,4 +8,4 @@ class TestDataclassSchemaFactory(TestCase):
 
     def test_non_dataclass(self):
         factory = DataclassSchemaFactory()
-        assert factory.create(str, get_default_schema_context()) is None
+        assert factory.create(str, None, get_default_schema_context()) is None
